.. cimsparql documentation master file, created by
   sphinx-quickstart on Thu Jan 30 18:42:05 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cimsparql's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README.md

   cimsparql

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
